@@ -353,7 +353,6 @@ async def present(
         )
 
         if not handle_operation_ret["result"]:
-            result["result"] = False
             result["comment"] += handle_operation_ret["comment"]
             result["rerun_data"] = handle_operation_ret["rerun_data"]
             return result
@@ -449,7 +448,6 @@ async def present(
                         ctx, operation_id, "compute.disk", True
                     )
                     if not op_ret["result"]:
-                        result["result"] = False
                         result["comment"] += op_ret["comment"]
                         result["rerun_data"] = op_ret["rerun_data"]
                         return result
@@ -493,7 +491,6 @@ async def present(
                         ctx, operation_id, "compute.disk", True
                     )
                     if not op_ret["result"]:
-                        result["result"] = False
                         result["comment"] += op_ret["comment"]
                         result["rerun_data"] = op_ret["rerun_data"]
                         return result
@@ -573,7 +570,6 @@ async def present(
                                 )
                             )
                             if not op_ret["result"]:
-                                result["result"] = False
                                 result["comment"] += op_ret["comment"]
                                 result["rerun_data"] = op_ret["rerun_data"]
                                 return result
@@ -604,7 +600,6 @@ async def present(
                                 )
                             )
                             if not op_ret["result"]:
-                                result["result"] = False
                                 result["comment"] += op_ret["comment"]
                                 result["rerun_data"] = op_ret["rerun_data"]
                                 return result
@@ -670,7 +665,6 @@ async def present(
         )
 
         if not handle_operation_ret["result"]:
-            result["result"] = False
             result["comment"] += handle_operation_ret["comment"]
             result["rerun_data"] = handle_operation_ret["rerun_data"]
             return result
@@ -796,7 +790,6 @@ async def absent(
             ctx, ctx.get("rerun_data"), "compute.disk"
         )
         if not handle_operation_ret["result"]:
-            result["result"] = False
             result["comment"] += handle_operation_ret["comment"]
             result["rerun_data"] = handle_operation_ret["rerun_data"]
             return result
@@ -840,3 +833,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         }
 
     return result
+
+
+def is_pending(hub, ret: dict, state: str = None, **pending_kwargs) -> bool:
+    return hub.tool.gcp.utils.is_pending(ret=ret, state=state, **pending_kwargs)
