@@ -127,6 +127,7 @@ async def present(
     ) = None,
     source_machine_image: str = None,
     resource_policies: List[str] = None,
+    status: str = None,
     tags: make_dataclass(
         "Tags",
         [
@@ -599,6 +600,20 @@ async def present(
         resource_policies(List[str], optional):
             Resource policies applied to this instance. Defaults to None.
 
+        status(str, Optional):
+            The status of the instance. One of the following values: PROVISIONING, STAGING, RUNNING, STOPPING, SUSPENDING, SUSPENDED, REPAIRING, and TERMINATED. For more information about the status of the instance, see Instance life cycle.
+                Enum type. Allowed values:
+                "DEPROVISIONING" - The Nanny is halted and we are performing tear down tasks like network deprogramming, releasing quota, IP, tearing down disks etc.
+                "PROVISIONING" - Resources are being allocated for the instance.
+                "REPAIRING" - The instance is in repair.
+                "RUNNING" - The instance is running.
+                "STAGING" - All required resources have been allocated and the instance is being started.
+                "STOPPED" - The instance has stopped successfully.
+                "STOPPING" - The instance is currently stopping (either being deleted or killed).
+                "SUSPENDED" - The instance has suspended.
+                "SUSPENDING" - The instance is suspending.
+                "TERMINATED" - The instance has stopped (either by explicit action or underlying failure). Defaults to None.
+
         tags(Dict[str, Any], optional):
             Tags to apply to this instance. Tags are used to identify valid sources or targets for network firewalls and are specified by the client during instance creation. The tags can be later modified by the setTags method. Each tag within the list must comply with RFC1035. Multiple tags can be specified via the 'tags.items' field.
                 Tags: A set of instance tags. Defaults to None.
@@ -1113,32 +1128,52 @@ async def present(
 
     if ctx.get("rerun_data"):
         handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, ctx.get("rerun_data"), "compute.instance"
+            ctx, ctx.get("rerun_data").get("operation_id"), "compute.instance"
         )
 
         if not handle_operation_ret["result"]:
-            result["result"] = False
             result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = handle_operation_ret["rerun_data"]
+            result["rerun_data"] = ctx.get("rerun_data")
             return result
 
         resource_id = handle_operation_ret["resource_id"]
 
+    get_resource_only_with_resource_id = hub.OPT.idem.get(
+        "get_resource_only_with_resource_id", False
+    )
     if resource_id:
         old_get_ret = await hub.exec.gcp.compute.instance.get(
             ctx, resource_id=resource_id
         )
 
-        if not old_get_ret["result"] or not old_get_ret["ret"]:
+        if not old_get_ret["result"] or (
+            not old_get_ret["ret"] and get_resource_only_with_resource_id
+        ):
             result["result"] = False
             result["comment"] += old_get_ret["comment"]
             return result
 
+        # long running operation has succeeded - both update and create
+        if ctx.get("rerun_data"):
+            result["new_state"] = old_get_ret["ret"]
+            result["old_state"] = ctx["rerun_data"]["old_state"]
+            if ctx["rerun_data"]["old_state"]:
+                result["comment"].append(
+                    hub.tool.gcp.comment_utils.update_comment(
+                        "gcp.compute.instance", name
+                    )
+                )
+            else:
+                result["comment"].append(
+                    hub.tool.gcp.comment_utils.create_comment(
+                        "gcp.compute.instance", name
+                    )
+                )
+            return result
+
         result["old_state"] = copy.deepcopy(copy.copy(old_get_ret["ret"]))
-    elif not hub.OPT.idem.get("get_resource_only_with_resource_id", False):
-        resource_id = (ctx.get("old_state") or {}).get(
-            "resource_id"
-        ) or hub.tool.gcp.resource_prop_utils.construct_resource_id(
+    elif not get_resource_only_with_resource_id:
+        resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
             "compute.instance", {**locals(), "instance": name}
         )
         old_get_ret = await hub.exec.gcp.compute.instance.get(
@@ -1184,6 +1219,7 @@ async def present(
         "can_ip_forward": can_ip_forward,
         "display_device": display_device,
         "zone": zone,
+        "status": status,
     }
 
     resource_body = {k: v for (k, v) in resource_body.items() if v is not None}
@@ -1197,13 +1233,8 @@ async def present(
         )
         result["old_state"]["zone"] = zone
 
-        # If rerun_data is set at this point this means that there has been a completed create or update operation
-        # so there is no need to run the code for create or update below again and we stop here
-        if ctx.get("rerun_data"):
-            result["new_state"] = result["old_state"]
-            return result
-
-        # TODO: if we fix isPending() to not update after creation we can make the fingerprint required upon update
+        # The fingerprint is required upon an update operation but in the time of creation the
+        # resource still do not have fingerprint so, we cannot make it a required param for present method.
         resource_body["fingerprint"] = fingerprint or result["old_state"].get(
             "fingerprint"
         )
@@ -1211,14 +1242,54 @@ async def present(
             "old_state"
         ].get("label_fingerprint")
 
-        old_network_interfaces = result["old_state"].get("network_interfaces")
+        # A dictionary of additional operations to perform on the object identified by the key
+        # the values are tuples with the first element - the method to call, the second element - arguments,
+        # third - the property is required in the end result
+        patch_operations_dict = {
+            "network_interfaces": (
+                hub.tool.gcp.compute.instance.update_network_interfaces,
+                (ctx, result["old_state"], network_interfaces),
+                True,
+            ),
+            "shielded_instance_config": (
+                hub.tool.gcp.compute.instance.update_shielded_instance_config,
+                (ctx, shielded_instance_config, None, None, None, resource_id),
+                False,
+            ),
+            "shielded_instance_integrity_policy": (
+                hub.tool.gcp.compute.instance.update_shielded_instance_integrity_policy,
+                (
+                    ctx,
+                    shielded_instance_integrity_policy,
+                    None,
+                    None,
+                    None,
+                    resource_id,
+                ),
+                False,
+            ),
+            "status": (
+                hub.tool.gcp.compute.instance.update_status,
+                (ctx, resource_id, result["old_state"].get("status"), status),
+                True,
+            ),
+        }
+
+        old_properties_dict = {
+            k: result["old_state"].get(k) for k in patch_operations_dict.keys()
+        }
+        changed_properties_dict = {
+            k: hub.tool.gcp.utils.compare_states(
+                {k: old_properties_dict.get(k, [])},
+                {k: resource_body.get(k, [])},
+                "compute.instance",
+            )
+            for k, v in patch_operations_dict.items()
+        }
+
         changes = hub.tool.gcp.utils.compare_states(
             result["old_state"],
-            {
-                "resource_id": resource_id,
-                **resource_body,
-                "network_interfaces": old_network_interfaces,
-            },
+            {"resource_id": resource_id, **resource_body, **old_properties_dict},
             "compute.instance",
         )
 
@@ -1240,16 +1311,10 @@ async def present(
                 result["new_state"] = copy.deepcopy(result["old_state"])
                 return result
 
-        network_interfaces_changed = hub.tool.gcp.utils.compare_states(
-            {"network_interfaces": old_network_interfaces or []},
-            {"network_interfaces": network_interfaces or []},
-            "compute.instance",
-        )
-
-        if not changes and not network_interfaces_changed:
+        if not changes and not any(changed_properties_dict.values()):
             result["result"] = True
             result["comment"].append(
-                hub.tool.gcp.comment_utils.already_exists_comment(
+                hub.tool.gcp.comment_utils.up_to_date_comment(
                     "gcp.compute.instance", name
                 )
             )
@@ -1266,21 +1331,17 @@ async def present(
             result["new_state"]["resource_id"] = resource_id
             return result
 
-        if network_interfaces_changed:
-            # Process network interfaces including access configs
-            update_network_interfaces_ret = (
-                await hub.tool.gcp.compute.instance.update_network_interfaces(
-                    ctx, result["old_state"], network_interfaces
-                )
-            )
+        for k, op in patch_operations_dict.items():
+            if changed_properties_dict[k]:
+                ret = await op[0](*op[1])
 
-            if not update_network_interfaces_ret["result"]:
-                result["comment"] += update_network_interfaces_ret["comment"]
-                result["result"] = False
-                return result
+                if not ret["result"]:
+                    result["comment"] += ret["comment"]
+                    result["result"] = False
+                    return result
 
         if changes:
-            if network_interfaces_changed:
+            if any(changed_properties_dict.values()):
                 get_ret = await hub.exec.gcp.compute.instance.get(
                     ctx, resource_id=resource_id
                 )
@@ -1289,17 +1350,18 @@ async def present(
                     result["comment"] += get_ret["comment"]
                     return result
 
-                # The network interfaces should be the same so update does not happen there
-                resource_body["network_interfaces"] = get_ret["ret"].get(
-                    "network_interfaces"
-                )
+                for k in patch_operations_dict.keys():
+                    resource_body[k] = get_ret["ret"].get(k)
+
                 resource_body["fingerprint"] = get_ret["ret"].get("fingerprint")
                 resource_body["label_fingerprint"] = get_ret["ret"].get(
                     "label_fingerprint"
                 )
 
-            if not resource_body.get("network_interfaces"):
-                resource_body["network_interfaces"] = old_network_interfaces
+            # put the old value of required properties in the resource body
+            for k, v in patch_operations_dict.items():
+                if v[2] and not resource_body.get(k):
+                    resource_body[k] = old_properties_dict[k]
 
             update_ret = await hub.exec.gcp_api.client.compute.instance.update(
                 hub,
@@ -1311,17 +1373,29 @@ async def present(
                 body=resource_body,
             )
 
-            if not update_ret["result"]:
+            if not update_ret["result"] or not update_ret["ret"]:
                 result["result"] = False
                 result["comment"] += update_ret["comment"]
                 return result
-            if update_ret["ret"] is not None:
-                if "compute#operation" in update_ret["ret"].get("kind", ""):
-                    operation = update_ret["ret"]
 
-        result["comment"].append(
-            hub.tool.gcp.comment_utils.update_comment("gcp.compute.instance", name)
-        )
+            if "compute#operation" in update_ret["ret"].get("kind", ""):
+                operation = update_ret["ret"]
+
+        if not changes and any(changed_properties_dict.values()):
+            get_ret = await hub.exec.gcp.compute.instance.get(
+                ctx, resource_id=resource_id
+            )
+            if not get_ret["result"] and not get_ret["ret"]:
+                result["result"] = False
+                result["comment"] += get_ret["comment"]
+                return result
+
+            result["new_state"] = get_ret["ret"]
+            result["comment"].append(
+                hub.tool.gcp.comment_utils.update_comment("gcp.compute.instance", name)
+            )
+            return result
+
     else:
         if ctx["test"]:
             result["comment"].append(
@@ -1343,7 +1417,7 @@ async def present(
             request_id=request_id,
             body=resource_body,
         )
-        if not create_ret["result"]:
+        if not create_ret["result"] or not create_ret["ret"]:
             result["result"] = False
             if create_ret["comment"] and next(
                 (
@@ -1358,44 +1432,23 @@ async def present(
                         "gcp.compute.instance", name
                     )
                 )
-                return result
             else:
                 result["comment"] += create_ret["comment"]
-        else:
-            result["comment"].append(
-                hub.tool.gcp.comment_utils.create_comment("gcp.compute.instance", name)
-            )
-            resource_id = create_ret["ret"].get("resource_id")
-        if create_ret["ret"] is not None:
-            if "compute#operation" in create_ret["ret"].get("kind", ""):
-                operation = create_ret["ret"]
+            return result
+
+        if "compute#operation" in create_ret["ret"].get("kind", ""):
+            operation = create_ret["ret"]
 
     if operation:
         operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
             operation.get("selfLink"), "compute.zone_operation"
         )
-        handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, operation_id, "compute.instance"
-        )
-
-        if not handle_operation_ret["result"]:
-            result["result"] = False
-            result["comment"] += handle_operation_ret["comment"]
-            result["rerun_data"] = handle_operation_ret["rerun_data"]
-            return result
-
-        resource_id = handle_operation_ret["resource_id"]
-
-    # Try getting the resource again
-    get_ret = await hub.exec.gcp.compute.instance.get(ctx, resource_id=resource_id)
-
-    if not get_ret["result"] and not get_ret["ret"]:
-        result["result"] = False
-        result["comment"] += get_ret["comment"]
+        result["rerun_data"] = {
+            "operation_id": operation_id,
+            "old_state": result["old_state"],
+        }
         return result
 
-    result["new_state"] = get_ret["ret"]
-
     return result
 
 
@@ -1508,7 +1561,6 @@ async def absent(
             ctx, ctx.get("rerun_data"), "compute.instance"
         )
         if not handle_operation_ret["result"]:
-            result["result"] = False
             result["comment"] += handle_operation_ret["comment"]
             result["rerun_data"] = handle_operation_ret["rerun_data"]
             return result
@@ -1552,3 +1604,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
             ]
         }
     return result
+
+
+def is_pending(hub, ret: dict, state: str = None, **pending_kwargs) -> bool:
+    return hub.tool.gcp.utils.is_pending(ret=ret, state=state, **pending_kwargs)
