@@ -390,7 +390,6 @@ async def absent(
             ctx, ctx.get("rerun_data"), "compute.resource_policy"
         )
         if not handle_operation_ret["result"]:
-            result["result"] = False
             result["comment"] += handle_operation_ret["comment"]
             result["rerun_data"] = handle_operation_ret["rerun_data"]
             return result
@@ -444,3 +443,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         }
 
     return result
+
+
+def is_pending(hub, ret: dict, state: str = None, **pending_kwargs) -> bool:
+    return hub.tool.gcp.utils.is_pending(ret=ret, state=state, **pending_kwargs)
