@@ -180,7 +180,6 @@ async def present(
         )
 
         if not op_ret["result"]:
-            result["result"] = False
             result["comment"] += op_ret["comment"]
             result["rerun_data"] = op_ret["rerun_data"]
             return result
@@ -302,7 +301,6 @@ async def present(
         )
 
         if not op_ret["result"]:
-            result["result"] = False
             result["comment"] += op_ret["comment"]
             result["rerun_data"] = op_ret["rerun_data"]
             return result
@@ -351,7 +349,6 @@ async def present(
             )
 
             if not handle_operation_ret["result"]:
-                result["result"] = False
                 result["comment"] += handle_operation_ret["comment"]
                 result["rerun_data"] = handle_operation_ret["rerun_data"]
                 return result
@@ -387,7 +384,6 @@ async def present(
             )
 
             if not handle_operation_ret["result"]:
-                result["result"] = False
                 result["comment"] += handle_operation_ret["comment"]
                 result["rerun_data"] = handle_operation_ret["rerun_data"]
                 return result
@@ -520,7 +516,6 @@ async def absent(
             ctx, ctx.get("rerun_data"), "compute.subnetwork"
         )
         if not op_ret["result"]:
-            result["result"] = False
             result["comment"] += op_ret["comment"]
             result["rerun_data"] = op_ret["rerun_data"]
             return result
@@ -566,3 +561,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         }
 
     return result
+
+
+def is_pending(hub, ret: dict, state: str = None, **pending_kwargs) -> bool:
+    return hub.tool.gcp.utils.is_pending(ret=ret, state=state, **pending_kwargs)
