@@ -25,8 +25,8 @@ def snake(hub, string: str) -> str:
     # Separate each camel-cased word into underscore delimited words
     string = re.sub("(.)([A-Z][a-z]+)", r"\1_\2", string)
     string = re.sub("([a-z0-9])([A-Z])", r"\1_\2", string)
-    # Replace special characters with underscores
-    string = re.sub(r"[^\w]", "_", string)
+    # Replace special characters with underscores except for [] and .
+    string = re.sub(r"[^\w\[\]\.]", "_", string)
     # make sure everything is lower-cased
     string = string.lower()
     string = string.replace("__", "_")
