@@ -38,6 +38,10 @@ def already_exists_comment(hub, resource_type: str, name: str) -> str:
     return f"{resource_type} '{name}' already exists."
 
 
+def up_to_date_comment(hub, resource_type: str, name: str) -> str:
+    return f"{resource_type} '{name}' is up to date."
+
+
 def update_tags_comment(hub, tags_to_remove, tags_to_add) -> str:
     return f"Update tags: Add keys {tags_to_add.keys()} Remove keys {tags_to_remove.keys()}"
 
