@@ -9,7 +9,7 @@ exec Sub for Google discovery-based Python client library APIs.
 The basic operating model is building Subs as needed to match the nature of a
 call to an exec. For example, a call like:
 
-    hub.exec.gcp.compute.instances.get(ctx, ...)
+    hub.exec.gcp.compute.instance.get(ctx, ...)
 
 will work, even though no exec subdirectories exist to match that call path.
 Instead, the API is dynamically discovered and built to match and tie
@@ -26,6 +26,7 @@ from pop.loader import LoadedMod
 from idem_gcp.helpers.exc import NotFoundError
 
 _GCP_SUB_CACHE = {}
+_GCP_RESOURCE_TYPES_CACHE = {}
 
 
 def resolve_sub(hub, ref: str, gcp_api):
@@ -33,19 +34,25 @@ def resolve_sub(hub, ref: str, gcp_api):
     Produces a callable from a string (dotted notation) call to an API.
     :param hub: The Hub into which the resolved callable will get placed.
     :param ref: The call path reference. For example:
-        "hub.exec.gcp.compute.instances.get".
+        "hub.exec.gcp.compute.instance.get".
     """
 
     def gen_sub(ref: str, gcp_api):
         callpath = ref.split(".")
         resource_type = ".".join(callpath[1:-1])
+        native_resource_type = hub.tool.gcp.resolver.find_native_resource_type(
+            resource_type
+        )
         method_name = callpath[-1]
+        callpath = callpath[0:1] + native_resource_type.split(".") + [callpath[-1]]
         callpath[0:-1] = [hub.tool.gcp.case.camel(v) for v in callpath[0:-1]]
 
         gcp_api_sub = gcp_api
         for c in callpath[1:]:
             gcp_api_sub = getattr(gcp_api_sub, c)
-        cm = ContractMod(hub, gcp_api_sub, resource_type, method_name)
+        cm = ContractMod(
+            hub, gcp_api_sub, resource_type, native_resource_type, method_name
+        )
         _GCP_SUB_CACHE[ref] = cm
         return cm
 
@@ -61,7 +68,9 @@ class ContractMod(LoadedMod):
     ComputeManagementClient.
     """
 
-    def __init__(self, hub, gcp_method, resource_type, method_name):
+    def __init__(
+        self, hub, gcp_method, resource_type, native_resource_type, method_name
+    ):
         """
         Initialize the instance.
         :param hub: The redistributed pop central hub to which to attach
@@ -73,6 +82,7 @@ class ContractMod(LoadedMod):
         self._hub = hub
         self._gcp_method = gcp_method
         self._resource_type = resource_type
+        self._native_resource_type = native_resource_type
         self._method_name = method_name
 
     @property
@@ -134,7 +144,9 @@ class ContractMod(LoadedMod):
         )
 
         # TODO: Fix projection required or not
-        if self._method_name in {"create"}:
+        if self._method_name in {"create"} and not self._resource_type.startswith(
+            "cloudkms"
+        ):
             raw_params["projection"] = "full"
 
         try:
@@ -154,11 +166,11 @@ class ContractMod(LoadedMod):
                 response[
                     "items"
                 ] = self._hub.tool.gcp.resolver.convert_dict_items_to_list(
-                    items, self._resource_type
+                    items, self._native_resource_type
                 )
 
             resource_type_camel = self._hub.tool.gcp.case.camel(
-                self._resource_type.split(".")[-1]
+                self._native_resource_type.split(".")[-1]
             )
             if resource_type_camel in response:
                 response["items"] = response[resource_type_camel]
@@ -177,11 +189,11 @@ class ContractMod(LoadedMod):
                         response[
                             "items"
                         ] = self._hub.tool.gcp.resolver.convert_dict_items_to_list(
-                            items, self._resource_type
+                            items, self._native_resource_type
                         )
 
                     resource_type_camel = self._hub.tool.gcp.case.camel(
-                        self._resource_type.split(".")[-1]
+                        self._native_resource_type.split(".")[-1]
                     )
                     if resource_type_camel in response:
                         response["items"] = response[resource_type_camel]
@@ -209,44 +221,54 @@ class ContractMod(LoadedMod):
 
 
 def process_response(hub, response: Dict, resource_type: str, method_name: str) -> Dict:
-    present_props_names = hub.tool.gcp.resource_prop_utils.get_present_properties(
-        resource_type
-    )
-
     # TODO: Get does not return all the necessary properties which should be the present properties so
     #  decide what to do
 
+    present_props_names = hub.tool.gcp.resource_prop_utils.get_present_properties(
+        resource_type
+    )
     singular_result_expected = hub.tool.gcp.resolver.has_singular_result(
         response, resource_type, method_name
     )
     if singular_result_expected:
-        present_item = hub.tool.gcp.resolver.filter_raw_properties_to_present(
-            response, present_props_names, resource_type
+        resource_id = hub.tool.gcp.resource_prop_utils.extract_resource_id(
+            response, resource_type
         )
-        # Single entry in call result, e.g. after get()/insert()/update() call
-        if present_item:
+        if resource_id:
+            present_item = hub.tool.gcp.resolver.filter_raw_properties_to_present(
+                response, present_props_names, resource_type, resource_id
+            )
             return present_item
+
+        return response
     else:
         # Multiple entries in call result, e.g. after list() call
         ret_items = []
         for service_resource in response.get("items") or {}:
-            present_item = hub.tool.gcp.resolver.filter_raw_properties_to_present(
-                service_resource, present_props_names, resource_type
+            resource_id = hub.tool.gcp.resource_prop_utils.extract_resource_id(
+                service_resource, resource_type
             )
-            if present_item:
-                ret_items.append(present_item)
+
+            present_item = None
+            if resource_id:
+                present_item = hub.tool.gcp.resolver.filter_raw_properties_to_present(
+                    service_resource, present_props_names, resource_type, resource_id
+                )
+
+            ret_items.append(present_item if present_item else service_resource)
+
         return {"items": ret_items}
 
+    return {}
+
 
 def filter_raw_properties_to_present(
-    hub, raw_props: Dict, present_properties_names: List, resource_type: str
+    hub,
+    raw_props: Dict,
+    present_properties_names: List,
+    resource_type: str,
+    resource_id: str,
 ) -> Dict:
-    resource_id = hub.tool.gcp.resource_prop_utils.extract_resource_id(
-        raw_props, resource_type
-    )
-    if not resource_id:
-        return None
-
     filtered = {
         key: value
         for key, value in raw_props.items()
@@ -287,3 +309,18 @@ def has_singular_result(
     if method_name in {"list", "aggregatedList", "describe"}:
         return False
     return True
+
+
+def find_native_resource_type(hub, resource_type: str) -> str:
+    def fetch_res_type_mapping(res_type: str) -> str:
+        hub_ref = hub.metadata.gcp
+        for part in res_type.split("."):
+            hub_ref = hub_ref[part]
+        try:
+            return hub_ref["NATIVE_RESOURCE_TYPE"]
+        except AttributeError:
+            return res_type
+
+    return _GCP_RESOURCE_TYPES_CACHE.get(
+        resource_type, fetch_res_type_mapping(resource_type)
+    )
