@@ -1,10 +1,12 @@
 import copy
+import re
 from typing import Any
 from typing import Dict
 from typing import List
 from typing import Set
 
 import yaml
+from deepdiff import DeepDiff
 from importlib_resources import files
 
 
@@ -14,12 +16,15 @@ def __init__(hub):
         .joinpath("properties.yaml")
         .read_text(encoding="utf-8")
     )
+
+    # TODO: Maybe convert the properties names in hub.tool.gcp.RESOURCE_PROPS
+    #  to snake case here so that we do not have to do conversion
+    #  very often anywhere these snake case properties names are needed.
+    #  Check if hub.tool.gcp.RESOURCE_PROPS are always convert to snake case
+
     hub.tool.gcp.RESOURCE_PROPS = yaml.safe_load(file_text)
 
 
-resource_id_delimiter = "^^^"
-
-
 def get_create_properties(hub, resource_type: str, convert_to_present=True) -> Set:
     resource_methods_properties = hub.tool.gcp.RESOURCE_PROPS[resource_type]
     raw_props = set(
@@ -72,9 +77,54 @@ def get_delete_properties(hub, resource_type: str, convert_to_present=True) -> S
 
 
 def get_non_updatable_properties(hub, resource_type: str) -> Set:
-    return hub.tool.gcp.resource_prop_utils.get_create_properties(
+    raw_nested_non_updatable_properties = hub.tool.gcp.RESOURCE_PROPS[
         resource_type
-    ) - hub.tool.gcp.resource_prop_utils.get_update_properties(resource_type)
+    ].get("nested_non_updatable_properties", [])
+
+    non_updatable_properties = set(
+        hub.tool.gcp.conversion_utils.convert_raw_properties_to_present(
+            raw_nested_non_updatable_properties
+        )
+    )
+
+    non_updatable_properties.update(
+        hub.tool.gcp.resource_prop_utils.get_create_properties(resource_type)
+        - hub.tool.gcp.resource_prop_utils.get_update_properties(resource_type)
+    )
+    return non_updatable_properties
+
+
+def get_changed_non_updatable_properties(
+    hub, resource_type: str, changes: DeepDiff
+) -> Set:
+    non_updatable_properties = (
+        hub.tool.gcp.resource_prop_utils.get_non_updatable_properties(resource_type)
+    )
+
+    changed_non_updatable_properties = set()
+    for changed_property_full_path in changes.affected_paths:
+        # This formats changed_property_full_path from e.g. "root['network_interfaces'][0]['alias_ip_ranges']"
+        # to "network_interfaces[].alias_ip_ranges"
+        changed_property_path_elements = re.findall(
+            r"(?<=\[).*?(?=\])", changed_property_full_path
+        )
+        formatted_path_elements = []
+        for i in range(len(changed_property_path_elements)):
+            if changed_property_path_elements[i].isdigit():
+                formatted_path_elements.append("[]")
+            else:
+                if i > 0:
+                    formatted_path_elements.append(".")
+                formatted_path_elements.append(
+                    changed_property_path_elements[i].strip("'")
+                )
+        formatted_property_path = "".join(formatted_path_elements)
+        for non_updatable_property_path in non_updatable_properties:
+            if non_updatable_property_path in formatted_property_path:
+                changed_non_updatable_properties.add(non_updatable_property_path)
+                break
+
+    return changed_non_updatable_properties
 
 
 def get_present_properties(hub, resource_type: str) -> Set:
@@ -92,7 +142,12 @@ def get_present_properties(hub, resource_type: str) -> Set:
 
 
 def get_exclude_paths(hub, resource_type: str) -> Set:
-    return set(hub.tool.gcp.RESOURCE_PROPS[resource_type].get("exclude_paths", {}))
+    raw_props_names = hub.tool.gcp.RESOURCE_PROPS[resource_type].get(
+        "exclude_paths", []
+    )
+    return set(
+        hub.tool.gcp.conversion_utils.convert_raw_properties_to_present(raw_props_names)
+    )
 
 
 def get_exclude_properties_from_transformation(
@@ -146,7 +201,7 @@ def extract_resource_id(hub, input_props: Dict, resource_type: str) -> Dict:
                 return input_props[resource_id_field]
 
 
-def get_resource_path(hub, resource_type: str) -> List:
+def get_resource_path(hub, resource_type: str) -> str:
     resource_path = resource_type.split(".")
     hub_ref = hub.metadata.gcp
     for resource_path_segment in resource_path:
@@ -220,6 +275,9 @@ def parse_link_to_resource_id(hub, link, resource_type: str):
     src = result.split("/")
     act = link.split("/")
 
+    if len(act) < len(src):
+        return None
+
     idx = -1
     for s in reversed(src):
         val = act[idx]
@@ -236,6 +294,29 @@ def parse_link_to_resource_id(hub, link, resource_type: str):
     return result
 
 
+def construct_resource_id(hub, resource_type: str, input_props: Dict[str, Any]) -> str:
+    if input_props is not None and input_props.get("name") is not None:
+        # handle case where "name" contains full resource id
+        name = input_props.get("name")
+        if (
+            hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
+                name, resource_type
+            )
+            is not None
+        ):
+            return name
+
+    resource_path = hub.tool.gcp.resource_prop_utils.get_resource_path(resource_type)
+    try:
+        filtered_without_none_properties = {
+            k: v for k, v in input_props.items() if v is not None
+        }
+        return resource_path.format(**filtered_without_none_properties)
+    except:
+        # a required input prop is missing or input_props is invalid format
+        return None
+
+
 def parse_link_to_zone(hub, link: str) -> str:
     return link.split("/")[-1]
 
@@ -265,7 +346,7 @@ def format_path_params(hub, resource, resource_type):
 # TODO: Remove this logic once we have all the nested properties defined for a method
 def are_properties_allowed_for_update(hub, resource_type, request_body):
     can_update = True
-    if resource_type == "compute.instances":
+    if resource_type == "compute.instance":
         for disk in request_body.get("disks" or {}):
             if disk.get("initialize_params"):
                 can_update = False
